
# import numpy as np

# arr = np.array([float(i) for i in input().split(',')]).reshape(*[int(i) for i in input().split(',')])
# u,v = np.linalg.eig(np.cov(((arr-np.mean(arr))/np.std(arr)).T))
# index = 0 if u[0]>u[1] else 1
# print('第1主成分={:.5f}*(x1-{:.2f}){:+.5f}*(x2-{:.2f})'.format(v[0][index],np.mean(arr,axis=0)[0],v[1][index],np.mean(arr,axis=0)[1]),end='')


def println():
    print(''' arr = np.array([float(i) for i in input().split(',')]).reshape(*[int(i) for i in input().split(',')])
u,v = np.linalg.eig(np.cov(((arr-np.mean(arr))/np.std(arr)).T))
index = 0 if u[0]>u[1] else 1
(''.format(v[0][index],np.mean(arr,axis=0)[0],v[1][index],np.mean(arr,axis=0)[1]),end='')''')


# import numpy as np
# from sklearn.cluster import KMeans


# arr = np.array([float(i) for i in input().split(' ')]).reshape(
#     *[int(i) for i in input().split(' ')])
# kmeans = KMeans(n_clusters=int(input())).fit(arr)
# print('A公司所在类的中心为：{:.2f},{:.2f}。'.format(kmeans.cluster_centers_[
#       kmeans.labels_[0], 0], kmeans.cluster_centers_[kmeans.labels_[0], 1]), end='')


def println():
    print(''' 
    arr = np.array([float(i) for i in input().split(' ')]).reshape(
    *[int(i) for i in input().split(' ')])
kmeans = KMeans(n_clusters=int(input())).fit(arr)
(''.format(kmeans.cluster_centers_[
      kmeans.labels_[0], 0], kmeans.cluster_centers_[kmeans.labels_[0], 1]), end='')
    
    ''')



# import numpy as np


# print(np.corrcoef(np.mat(np.array([float(i)
#       for i in input().split()]).reshape(-1, 31))))


def println():
    print('''
    np.corrcoef(np.mat(np.array([float(i)
                 for i in input().split()]).reshape(-1, 31)))
    ''')



"""
NumPy_msa
=====

Provides
  1. An array object of arbitrary homogeneous items
  2. Fast mathematical operations over arrays
  3. Linear Algebra, Fourier Transforms, Random Number Generation

How to use the documentation
----------------------------
Documentation is available in two forms: docstrings provided
with the code, and a loose standing reference guide, available from
`the NumPy homepage <https://www.scipy.org>`_.

We recommend exploring the docstrings using
`IPython <https://ipython.org>`_, an advanced Python shell with
TAB-completion and introspection capabilities.  See below for further
instructions.

The docstring examples assume that `numpy` has been imported as `np`::

  >>> import numpy as np

Code snippets are indicated by three greater-than signs::

  >>> x = 42
  >>> x = x + 1

Use the built-in ``help`` function to view a function's docstring::

  >>> help(np.sort)
  ... # doctest: +SKIP

For some objects, ``np.info(obj)`` may provide additional help.  This is
particularly true if you see the line "Help on ufunc object:" at the top
of the help() page.  Ufuncs are implemented in C, not Python, for speed.
The native Python help() does not know how to view their help, but our
np.info() function does.

To search for documents containing a keyword, do::

  >>> np.lookfor('keyword')
  ... # doctest: +SKIP

General-purpose documents like a glossary and help on the basic concepts
of numpy are available under the ``doc`` sub-module::

  >>> from numpy import doc
  >>> help(doc)
  ... # doctest: +SKIP

Available subpackages
---------------------
doc
    Topical documentation on broadcasting, indexing, etc.
lib
    Basic functions used by several sub-packages.
random
    Core Random Tools
linalg
    Core Linear Algebra Tools
fft
    Core FFT routines
polynomial
    Polynomial tools
testing
    NumPy testing tools
f2py
    Fortran to Python Interface Generator.
distutils
    Enhancements to distutils with support for
    Fortran compilers support and more.

Utilities
---------
test
    Run numpy unittests
show_config
    Show numpy build configuration
dual
    Overwrite certain functions with high-performance SciPy tools.
    Note: `numpy.dual` is deprecated.  Use the functions from NumPy or Scipy
    directly instead of importing them from `numpy.dual`.
matlib
    Make everything matrices.
__version__
    NumPy version string

Viewing documentation using IPython
-----------------------------------
Start IPython with the NumPy profile (``ipython -p numpy``), which will
import `numpy` under the alias `np`.  Then, use the ``cpaste`` command to
paste examples into the shell.  To see which functions are available in
`numpy`, type ``np.<TAB>`` (where ``<TAB>`` refers to the TAB key), or use
``np.*cos*?<ENTER>`` (where ``<ENTER>`` refers to the ENTER key) to narrow
down the list.  To view the docstring for a function, use
``np.cos?<ENTER>`` (to view the docstring) and ``np.cos??<ENTER>`` (to view
the source code).

Copies vs. in-place operation
-----------------------------
Most of the functions in `numpy` return a copy of the array argument
(e.g., `np.sort`).  In-place versions of these functions are often
available as array methods, i.e. ``x = np.array([1,2,3]); x.sort()``.
Exceptions to this rule are documented.

"""

from . import example
from . import vals_vectors
from . import classify
from . import corrcoef
from . import k_means
from . import labels
from . import linear_predict
from . import pca
from . import help_h




'''
Find the eigenvalues ​​and eigenvectors of a random matrix

====

For example 

Input 25 integer data, then convert it into a 5X5 matrix, find its eigenvalues ​​and eigenvectors, 
please refer to the sample for the correct input format, if the input format is not int or the number of inputs is wrong, 
the output: the input has wrong!



Provides
  1. An array object of arbitrary homogeneous items
  2. Fast mathematical operations over arrays
  3. Linear Algebra, Fourier Transforms, Random Number Generation


How to use the documentation
----------------------------
Documentation is available in two forms: docstrings provided
with the code, and a loose standing reference guide, available from
`the NumPy homepage <https://www.scipy.org>`_.

We recommend exploring the docstrings using
`IPython <https://ipython.org>`_, an advanced Python shell with
TAB-completion and introspection capabilities.  See below for further
instructions.


'''

# import numpy as np

# try:
#     a, b = np.linalg.eig(np.array([int(i)
#                          for i in input().split(' ')]).reshape(5, 5))
#     print(a, '\n', b)
# except:
#     print('输入有错！')


def println():
    print(''' 
    a,b = np.linalg.eig(np.array([int(i) for i in input().split(' ')]).reshape(5,5))
    ''')



def help():
    print(''' 
    
    usage: D:\python.exe [option] ... [-c cmd | -m mod | file | -] [arg] ...
Options and arguments (and corresponding environment variables):
-b     : issue warnings about str(bytes_instance), str(bytearray_instance)
         and comparing bytes/bytearray with str. (-bb: issue errors)
-B     : don't write .pyc files on import; also PYTHONDONTWRITEBYTECODE=x
-c cmd : program passed in as string (terminates option list)
-d     : turn on parser debugging output (for experts only, only works on
         debug builds); also PYTHONDEBUG=x
-E     : ignore PYTHON* environment variables (such as PYTHONPATH)
-h     : print this help message and exit (also --help)
-i     : inspect interactively after running script; forces a prompt even
         if stdin does not appear to be a terminal; also PYTHONINSPECT=x
-I     : isolate Python from the user's environment (implies -E and -s)
-m mod : run library module as a script (terminates option list)
-O     : remove assert and __debug__-dependent statements; add .opt-1 before
         .pyc extension; also PYTHONOPTIMIZE=x
-OO    : do -O changes and also discard docstrings; add .opt-2 before
         .pyc extension
-q     : don't print version and copyright messages on interactive startup
-s     : don't add user site directory to sys.path; also PYTHONNOUSERSITE
-S     : don't imply 'import site' on initialization
-u     : force the stdout and stderr streams to be unbuffered;
         this option has no effect on stdin; also PYTHONUNBUFFERED=x
-v     : verbose (trace import statements); also PYTHONVERBOSE=x
         can be supplied multiple times to increase verbosity
-V     : print the Python version number and exit (also --version)
         when given twice, print more information about the build
-W arg : warning control; arg is action:message:category:module:lineno
         also PYTHONWARNINGS=arg
-x     : skip first line of source, allowing use of non-Unix forms of #!cmd
-X opt : set implementation-specific option. The following options are available:
-e      : example ignore PYTHON* environment variables (such as PYTHONPATH)
-v      :vals_vectors run library module as a script (terminates option list)
-c      : classify print this help message and exit (also --help)
-o      : corrcoef verbose (trace import statements); also PYTHONVERBOSE=x
-k      : k_means issue warnings about str(bytes_instance), str(bytearray_instance)
         and comparing bytes/bytearray with str. (-bb: issue errors)
-l      : labels don't print version and copyright messages on interactive startup
-i      : linear_predict inspect interactively after running script; forces a prompt even
         if stdin does not appear to be a terminal; also PYTHONINSPECT=x
-p      : pca inspect interactively after running script; forces a prompt even
         if stdin does not appear to be a terminal; also PYTHONINSPECT=x
== help -h

         -X faulthandler: enable faulthandler
         -X oldparser: enable the traditional LL(1) parser; also PYTHONOLDPARSER
         -X showrefcount: output the total reference count and number of used
             memory blocks when the program finishes or after each statement in the
             interactive interpreter. This only works on debug builds
         -X tracemalloc: start tracing Python memory allocations using the
             tracemalloc module. By default, only the most recent frame is stored in a
             traceback of a trace. Use -X tracemalloc=NFRAME to start tracing with a
             traceback limit of NFRAME frames
         -X importtime: show how long each import takes. It shows module name,
             cumulative time (including nested imports) and self time (excluding
             nested imports). Note that its output may be broken in multi-threaded
             application. Typical usage is python3 -X importtime -c 'import asyncio'
         -X dev: enable CPython's "development mode", introducing additional runtime
             checks which are too expensive to be enabled by default. Effect of the
             developer mode:
                * Add default warning filter, as -W default
                * Install debug hooks on memory allocators: see the PyMem_SetupDebugHooks() C function
                * Enable the faulthandler module to dump the Python traceback on a crash
                * Enable asyncio debug mode
                * Set the dev_mode attribute of sys.flags to True
                * io.IOBase destructor logs close() exceptions
         -X utf8: enable UTF-8 mode for operating system interfaces, overriding the default
             locale-aware mode. -X utf8=0 explicitly disables UTF-8 mode (even when it would        
             otherwise activate automatically)
         -X pycache_prefix=PATH: enable writing .pyc files to a parallel tree rooted at the
             given directory instead of to the code tree

--check-hash-based-pycs always|default|never:
    control how Python invalidates hash-based .pyc files
file   : program read from script file
-      : program read from stdin (default; interactive mode if a tty)
arg ...: arguments passed to program in sys.argv[1:]

Other environment variables:
PYTHONSTARTUP: file executed on interactive startup (no default)
PYTHONPATH   : ';'-separated list of directories prefixed to the
               default module search path.  The result is sys.path.
PYTHONHOME   : alternate <prefix> directory (or <prefix>;<exec_prefix>).
               The default module search path uses <prefix>\python{major}{minor}.
PYTHONPLATLIBDIR : override sys.platlibdir.
PYTHONCASEOK : ignore case in 'import' statements (Windows).
PYTHONUTF8: if set to 1, enable the UTF-8 mode.
PYTHONIOENCODING: Encoding[:errors] used for stdin/stdout/stderr.
PYTHONFAULTHANDLER: dump the Python traceback on fatal errors.
PYTHONHASHSEED: if this variable is set to 'random', a random value is used
   to seed the hashes of str and bytes objects.  It can also be set to an
   integer in the range [0,4294967295] to get hash values with a
   predictable seed.
PYTHONMALLOC: set the Python memory allocators and/or install debug hooks
   on Python memory allocators. Use PYTHONMALLOC=debug to install debug
   hooks.
PYTHONCOERCECLOCALE: if this variable is set to 0, it disables the locale
   coercion behavior. Use PYTHONCOERCECLOCALE=warn to request display of
   locale coercion and locale compatibility warnings on stderr.
PYTHONBREAKPOINT: if this variable is set to 0, it disables the default
   debugger. It can be set to the callable of your debugger of choice.
PYTHONDEVMODE: enable the development mode.
PYTHONPYCACHEPREFIX: root directory for bytecode cache (pyc) files.
    ''')



# import numpy as np

# from sklearn.linear_model import LinearRegression

# print("Predict 12 inch cost:$%.2f" % (LinearRegression().fit(np.mat(list(map(int, input().split(' ')))).reshape(
#     5, 1), np.mat(list(map(float, input().split(' ')))).reshape(5, 1)).predict([[int(input())]])), end="")


def println():
    print(''' 
    (LinearRegression().fit(np.mat(list(map(int,input().split(' ')))).reshape(5,1),np.mat(list(map(float,input().split(' ')))).reshape(5,1)).predict([[int(input())]])), end="")
    
    ''')



# import numpy as np

# from sklearn.cluster import AgglomerativeClustering

# arr = np.array([float(i) for i in input().split(' ')]).reshape(
#     *[int(i) for i in input().split(' ')])

# res = AgglomerativeClustering(int(input())).fit(arr.T).labels_
# print("香气和酸质{val}属于一类。".format(val='' if res[0] == res[2] else '不'), end='')


























def println():
    print(''' arr = np.array([float(i) for i in input().split(' ')]).reshape(*[int(i) for i in input().split(' ')])
res = AgglomerativeClustering(int(input())).fit(arr.T).labels_
("".format(val = '' if res[0]==res[2] else '不'),end='')''')



from numpy import *
import numpy as np
import math


def fun():
    x1 = array([float(i) for i in input().split(',')])
    y1 = array([float(i) for i in input().split(',')])
    w1 = mat(vstack((x1, y1)))
    x2 = array([float(i) for i in input().split(',')])
    y2 = array([float(i) for i in input().split(',')])
    w2 = mat(vstack((x2, y2)))
    mean1 = np.mean(w1, 1)
    mean2 = np.mean(w2, 1)
    dimens1, nums1 = w1.shape[:2]
    samples_mean1 = w1 - mean1
    s_in1 = 0
    for i in range(nums1):
        x = samples_mean1[:, i]
        s_in1 += dot(x, x.T)
    dimens2, nums2 = w2.shape[:2]
    samples_mean2 = w2 - mean2
    s_in2 = 0
    for i in range(nums2):
        x = samples_mean2[:, i]
        s_in2 += dot(x, x.T)
    s = s_in1 + s_in2
    s_t = s.I
    w = dot(s_t, mean1 - mean2)
    w_new = w.T
    m1_new = dot(w_new, mean1)
    m2_new = dot(w_new, mean2)
    pw1 = 0.6
    pw2 = 0.4
    w0 = m1_new*pw1+m2_new*pw2
    x = mat(array([float(i) for i in input().split(',')]).reshape(2, 1))
    y_i = w_new * x[:, 0]
    if y_i > w0:
        print('该点属于第一类')
    else:
        print('该点属于第二类')


# fun()
